@@ -17,6 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <atk/atk.h>
 #include <gtk/gtk.h>
@@ -617,7 +618,7 @@ gail_accessibility_module_init (void)
     }
   gail_initialized = TRUE;
 
-  g_print ("GTK Accessibility Module initialized\n");
+  fprintf (stderr, "GTK Accessibility Module initialized\n");
 
   GAIL_WIDGET_SET_FACTORY (GTK_TYPE_WIDGET, gail_widget);
   GAIL_WIDGET_SET_FACTORY (GTK_TYPE_CONTAINER, gail_container);
@@ -702,7 +703,7 @@ gnome_accessibility_module_shutdown (void)
     }
   gail_initialized = FALSE;
 
-  g_print("Gtk Accessibilty Module shutdown\n");
+  fprintf (stderr, "Gtk Accessibilty Module shutdown\n");
 
   /* FIXME: de-register the factory types so we can unload ? */
 }
